[][src]Trait typemap::DebugAny

pub trait DebugAny: Any + Debug { }

A marker trait meant for use as the A parameter in TypeMap.

This can be used to construct TypeMaps containing only types which implement Debug like so: TypeMap::<DebugAny>::custom(), which produces a TypeMap<DebugAny>. Combine DebugAny with Send or Sync to add additional bounds.

There is also an exported alias for this type of TypeMap, DebugMap.